==> CedarBackup2-2.10.1.tar.gz: CedarBackup2-2.10.1/CedarBackup2/actions/__init__.py <==
# -*- coding: iso-8859-1 -*-
# vim: set ft=python ts=3 sw=3 expandtab:
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
#              C E D A R
#          S O L U T I O N S       "Software done right."
#           S O F T W A R E
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Author   : Kenneth J. Pronovici <pronovic@ieee.org>
# Language : Python (>= 2.3)
# Project  : Official Cedar Backup Extensions
# Revision : $Id: __init__.py 1046 2007-01-05 01:18:32Z pronovic $
# Purpose  : Provides package initialization
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

########################################################################
# Module documentation
########################################################################

"""
Cedar Backup actions.

This package code related to the offical Cedar Backup actions (collect,
stage, store, purge, rebuild, and validate).

The action modules consist of mostly "glue" code that uses other lower-level
functionality to actually implement a backup.  There is one module for each
high-level backup action, plus a module that provides shared constants.

All of the public action function implement the Cedar Backup Extension
Architecture Interface, i.e. the same interface that extensions implement.

@author: Kenneth J. Pronovici <pronovic@ieee.org>
"""


########################################################################
# Package initialization
########################################################################

# Using 'from CedarBackup2.actions import *' will just import the modules listed
# in the __all__ variable.

__all__ = [ 'constants', 'collect', 'stage', 'store', 'purge', 'rebuild', 'validate', ]

==> CedarBackup2-2.12.1.tar.gz: CedarBackup2-2.12.1/CedarBackup2/actions/__init__.py <==
# -*- coding: iso-8859-1 -*-
# vim: set ft=python ts=3 sw=3 expandtab:
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
#              C E D A R
#          S O L U T I O N S       "Software done right."
#           S O F T W A R E
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #
#
# Author   : Kenneth J. Pronovici <pronovic@ieee.org>
# Language : Python (>= 2.3)
# Project  : Official Cedar Backup Extensions
# Revision : $Id: __init__.py 1136 2007-02-23 05:25:10Z pronovic $
# Purpose  : Provides package initialization
#
# # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # #

########################################################################
# Module documentation
########################################################################

"""
Cedar Backup actions.

This package code related to the offical Cedar Backup actions (collect,
stage, store, purge, rebuild, and validate).

The action modules consist of mostly "glue" code that uses other lower-level
functionality to actually implement a backup.  There is one module for each
high-level backup action, plus a module that provides shared constants.

All of the public action function implement the Cedar Backup Extension
Architecture Interface, i.e. the same interface that extensions implement.

@author: Kenneth J. Pronovici <pronovic@ieee.org>
"""


########################################################################
# Package initialization
########################################################################

# Using 'from CedarBackup2.actions import *' will just import the modules listed
# in the __all__ variable.

__all__ = [ 'constants', 'collect', 'stage', 'store', 'purge', 'util', 'rebuild', 'validate', ]
